@@ -2,7 +2,7 @@
 import os
 
 from luscious_dl.logger import logger
-from luscious_dl.utils import cls, create_default_files, open_config_menu, get_config_setting, list_organizer
+from luscious_dl.utils import cls, create_default_files, open_config_menu, get_config_setting, list_organizer, read_list
 from luscious_dl.downloader import Downloader
 from luscious_dl.parser import extract_album_id, extract_user_id, is_a_valid_id
 from luscious_dl.start import albums_download, users_download
@@ -29,39 +29,33 @@ def menu() -> None:
     cls()
 
     if option == '1':
-      input_url_or_ids = input('0 - Back.\nAlbum URL/ID: ')
+      input_url_or_ids = input('0 - Back.\nEnter album URL or ID.\n>')
       if input_url_or_ids != '0':
         cls()
         inputs = [input_.strip() for input_ in input_url_or_ids.split(',')]
         albums_ids = set(int(input_) if is_a_valid_id(input_) else extract_album_id(input_) for input_ in inputs)
         albums_download(albums_ids, downloader)
-        for id_ in albums_ids:
-          list_organizer(f'Album: {id_}')
+        for input_ in inputs:
+          list_organizer(f'album-{int(input_)}' if is_a_valid_id(input_) else input_)
         logger.log(5, 'Album urls added to completed list.')
-      else:
-        cls()
 
     elif option == '2':
-      input_user_url_or_id = input('0 - Back.\nUser URL/ID: ')
+      input_user_url_or_id = input('0 - Back.\nEnter user URL or ID.\n>')
       if input_user_url_or_id != '0':
         cls()
         inputs = [id_.strip() for id_ in input_user_url_or_id.split(',')]
         users_ids = set(int(input_) if is_a_valid_id(input_) else extract_user_id(input_) for input_ in inputs)
         users_download(users_ids, downloader)
-        for id_ in users_ids:
-          list_organizer(f'User: {id_}')
+        for input_ in inputs:
+          list_organizer(f'user-{int(input_)}' if is_a_valid_id(input_) else input_)
         logger.log(5, 'Users urls added to completed list.')
 
     elif option == '3':
-      logger.log(5, 'Checking List.')
-      with open('./list.txt') as x:
-        list_txt = x.read().split('\n')
-        logger.log(5, f'Total of Links: {len(list_txt)}.')
+      list_txt = read_list()
       albums_ids = set(int(input_) if is_a_valid_id(input_) else extract_album_id(input_) for input_ in list_txt)
       albums_download(albums_ids, downloader)
-      for id_ in albums_ids:
-        list_organizer(f'Album: {id_}')
-      logger.log(5, 'Album urls added to completed list.')
+      for item in list_txt:
+        list_organizer(f'album-{int(item)}' if is_a_valid_id(item) else item)
 
     elif option == '4':
       open_config_menu()
