@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 import os
 import json
-from typing import Any
+from typing import Any, List
+
+from luscious_dl.parser import is_a_valid_id
 
 from luscious_dl.logger import logger
 
@@ -10,12 +12,27 @@ def cls() -> None:
   os.system('cls' if os.name == 'nt' else 'clear')
 
 
+def format_filename(name: str) -> str:
+  pass
+
+
 def get_config_setting(setting: str) -> Any:
   with open('./config.json') as config:
     data = json.load(config)
   return data[setting]
 
 
+def read_list() -> List[str]:
+  try:
+    logger.log(5, 'Reading list...')
+    with open('./list.txt') as file:
+      list_txt = file.read().split('\n')
+      logger.log(5, f'Total of Links: {len(list_txt)}.')
+    return list_txt
+  except Exception as e:
+    print(f'Failed to read the list.txt.\n{e}')
+
+
 def create_default_files() -> None:
   if not os.path.exists('./config.json'):
     data = {
@@ -44,9 +61,9 @@ def create_folder(directory: str) -> None:
     logger.error(f'Creating directory in: {directory}')
 
 
-def list_organizer(album_url: str) -> None:
+def list_organizer(string: str) -> None:
   with open('./list.txt') as list_txt:
-    temp = ['' if album_url in line else line for line in list_txt]
+    temp = ['' if string in line else line for line in list_txt]
   with open('./list.txt', 'w') as list_txt:
     for line in temp:
       list_txt.write(line)
@@ -55,7 +72,8 @@ def list_organizer(album_url: str) -> None:
   with open('./list_completed.txt', 'a') as completed:
     if not text.endswith('\n'):
       completed.write('\n')
-    completed.write(album_url)
+    completed.write(string)
+    logger.log(5, f'Added to completed list: {string}')
 
 
 def open_config_menu() -> None:
